summaryrefslogtreecommitdiff
path: root/sys/arch/i386
diff options
context:
space:
mode:
authorMartin Pieuchot <mpi@cvs.openbsd.org>2016-02-27 13:08:08 +0000
committerMartin Pieuchot <mpi@cvs.openbsd.org>2016-02-27 13:08:08 +0000
commitb2f97f2ae592bb15002759d8300624750ab10eff (patch)
tree516aba0f8239ca6eb161284d94ceaf4b10b74d6d /sys/arch/i386
parent8115b491c372ec13e6406e31e006f1924e62218b (diff)
Rename kdb_trap() into db_ktrap().
The goal is to include it in the list of functions that must not be instrumented. All ddb(8) functions should be in this list and have their names start with 'db_'. ok visa@, deraadt@
Diffstat (limited to 'sys/arch/i386')
-rw-r--r--sys/arch/i386/i386/db_interface.c6
-rw-r--r--sys/arch/i386/i386/trap.c6
-rw-r--r--sys/arch/i386/include/db_machdep.h4
3 files changed, 8 insertions, 8 deletions
diff --git a/sys/arch/i386/i386/trap.c b/sys/arch/i386/i386/trap.c
index 55f45f87a59..cae218755eb 100644
--- a/sys/arch/i386/i386/trap.c
+++ b/sys/arch/i386/i386/trap.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: trap.c,v 1.123 2015/06/28 01:11:27 guenther Exp $ */
+/* $OpenBSD: trap.c,v 1.124 2016/02/27 13:08:07 mpi Exp $ */
/* $NetBSD: trap.c,v 1.95 1996/05/05 06:50:02 mycroft Exp $ */
/*-
@@ -186,7 +186,7 @@ trap(struct trapframe *frame)
#endif
#ifdef DDB
- if (kdb_trap(type, 0, frame))
+ if (db_ktrap(type, 0, frame))
return;
#endif
if (frame->tf_trapno < trap_types)
@@ -498,7 +498,7 @@ trap(struct trapframe *frame)
return;
#endif
#ifdef DDB
- if (kdb_trap(type, 0, frame))
+ if (db_ktrap(type, 0, frame))
return;
#endif
#endif /* DDB || KGDB */
diff --git a/sys/arch/i386/include/db_machdep.h b/sys/arch/i386/include/db_machdep.h
index 537eea6baf8..77ca36b80c9 100644
--- a/sys/arch/i386/include/db_machdep.h
+++ b/sys/arch/i386/include/db_machdep.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: db_machdep.h,v 1.23 2014/03/16 20:31:46 guenther Exp $ */
+/* $OpenBSD: db_machdep.h,v 1.24 2016/02/27 13:08:07 mpi Exp $ */
/* $NetBSD: db_machdep.h,v 1.9 1996/05/03 19:23:59 christos Exp $ */
/*
@@ -84,7 +84,7 @@ typedef long kgdb_reg_t;
/* macro for checking if a thread has used floating-point */
-int kdb_trap(int, int, db_regs_t *);
+int db_ktrap(int, int, db_regs_t *);
void db_machine_init(void);
int db_enter_ddb(void);
diff --git a/sys/arch/i386/i386/db_interface.c b/sys/arch/i386/i386/db_interface.c
index 13cd5be101d..19694f7af76 100644
--- a/sys/arch/i386/i386/db_interface.c
+++ b/sys/arch/i386/i386/db_interface.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: db_interface.c,v 1.31 2014/09/14 14:17:23 jsg Exp $ */
+/* $OpenBSD: db_interface.c,v 1.32 2016/02/27 13:08:07 mpi Exp $ */
/* $NetBSD: db_interface.c,v 1.22 1996/05/03 19:42:00 christos Exp $ */
/*
@@ -98,10 +98,10 @@ kdbprinttrap(int type, int code)
}
/*
* kdb_trap - field a TRACE or BPT trap
*/
int
-kdb_trap(int type, int code, db_regs_t *regs)
+db_ktrap(int type, int code, db_regs_t *regs)
{
int s;
@@ -98,10 +98,10 @@ kdbprinttrap(int type, int code)
}
/*
- * kdb_trap - field a TRACE or BPT trap
+ * db_ktrap - field a TRACE or BPT trap
*/
int